@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use TestLogger;
 use base qw/Catalyst/;
-use Catalyst qw/Params::Nested/;
+use Catalyst qw//;
 
 __PACKAGE__->config('name' => 'TestAppWithoutUnicode');
 
